pub struct AudioEndedPayload {
pub session_id: u64,
pub path: String,
}Fields
session_id: u64path: StringTrait Implementations
Sourceimpl Clone for AudioEndedPayload
impl Clone for AudioEndedPayload
Sourcefn clone(&self) -> AudioEndedPayload
fn clone(&self) -> AudioEndedPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioEndedPayload
impl Debug for AudioEndedPayload
Sourceimpl<'de> Deserialize<'de> for AudioEndedPayload
impl<'de> Deserialize<'de> for AudioEndedPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioEndedPayload
Sourceimpl PartialEq for AudioEndedPayload
impl PartialEq for AudioEndedPayload
Sourcefn eq(&self, other: &AudioEndedPayload) -> bool
fn eq(&self, other: &AudioEndedPayload) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AudioEndedPayload
impl Serialize for AudioEndedPayload
impl StructuralPartialEq for AudioEndedPayload
Sourceimpl Type for AudioEndedPayload
impl Type for AudioEndedPayload
Sourcefn definition(types: &mut TypeCollection) -> DataType
fn definition(types: &mut TypeCollection) -> DataType
returns a
DataType that represents the type.
This will also register this and any dependent types into the TypeCollection.Auto Trait Implementations
impl Freeze for AudioEndedPayload
impl RefUnwindSafe for AudioEndedPayload
impl Send for AudioEndedPayload
impl Sync for AudioEndedPayload
impl Unpin for AudioEndedPayload
impl UnsafeUnpin for AudioEndedPayload
impl UnwindSafe for AudioEndedPayload